KinesisDataset.Kinesis is a managed service provided by AWS for data streaming.
This dataset reads messages from Kinesis with each message presented
as a tf.string.
kinesis_dataset(stream, shard = "", read_indefinitely = TRUE, interval = 1e+05)A tf.string tensor containing the name of the stream.
A tf.string tensor containing the id of the shard.
If True, the Kinesis dataset will keep retry again
on EOF after the interval period. If False, then the dataset will
stop on EOF. The default value is True.
The interval for the Kinesis Client to wait before it tries to get records again (in millisecond).